@@ -6,12 +6,24 @@ from einops import rearrange
 
 import fairseq
 
+from torchaudio.functional import resample
+
+from audiolm_pytorch.utils import curtail_to_multiple
+
+def exists(val):
+    return val is not None
+
 class FairseqVQWav2Vec(nn.Module):
     def __init__(
         self,
-        checkpoint_path
+        checkpoint_path,
+        target_sample_khz = 24000,
+        seq_len_multiple_of = None
     ):
         super().__init__()
+        self.target_sample_khz = target_sample_khz
+        self.seq_len_multiple_of = seq_len_multiple_of
+
         path = Path(checkpoint_path)
         assert path.exists(), f'path {checkpoint_path} does not exist'
 
@@ -31,7 +43,18 @@ class FairseqVQWav2Vec(nn.Module):
         return self.model.vector_quantizer.embedding.shape[0]
 
     @torch.no_grad()
-    def forward(self, wav_input, flatten = True):
+    def forward(
+        self,
+        wav_input,
+        flatten = True,
+        input_sample_khz = None
+    ):
+        if exists(input_sample_khz):
+            wav_input = resample(wav_input, input_sample_khz, self.target_sample_khz)
+
+        if exists(self.seq_len_multiple_of):
+            wav_input = curtail_to_multiple(wav_input, self.seq_len_multiple_of)
+
         embed = self.model.feature_extractor(wav_input)
         _, codebook_indices = self.model.vector_quantizer.forward_idx(embed)
 
